@@ -69,9 +69,9 @@ class Migration(migrations.Migration):
                 ("ocp_project",
                  models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="app_env_ocp_project",
                                    to="ocp_project_plugin.OCPProject")),
-                ("requests_cpu", models.CharField(max_length=5, null=True)),
+                ("requests_cpu", models.DecimalField(max_digits=4, decimal_places=2, null=True)),
                 ("requests_memory", models.CharField(max_length=5, null=True)),
-                ("limits_cpu", models.CharField(max_length=5, null=True)),
+                ("limits_cpu", models.DecimalField(max_digits=4, decimal_places=2, null=True)),
                 ("limits_memory", models.CharField(max_length=5, null=True)),
             ],
             options={
