@@ -1,4 +1,3 @@
-import logging
 from decimal import Decimal
 from django.core.validators import RegexValidator
 from django.db.models import CharField, BooleanField, ForeignKey, CASCADE, OneToOneField, SET_NULL, PROTECT, \
@@ -10,6 +9,9 @@ from netbox import settings
 from ocp_project_plugin.choices import AppEnvironmentClusterEnvChoices, AppEnvironmentDeploymentKindChoices
 
 from netbox.models import NetBoxModel
+from tenancy.models import ContactAssignment, ContactRole
+
+from django.contrib.contenttypes.models import ContentType
 
 PLUGIN_SETTINGS = settings.PLUGINS_CONFIG.get('ocp_project_plugin', dict())
 CPU_COST = PLUGIN_SETTINGS.get('cpu_cost', '')
@@ -71,6 +73,7 @@ class OCPProject(NetBoxModel):
                     "request"]
 
     class Meta:
+        verbose_name = "OCP Project"
         ordering = ["name", "description", "display_name", "owner", "contact", "customer", "docu_url", "workload",
                     "request"]
 
@@ -84,88 +87,29 @@ class OCPProject(NetBoxModel):
     def docs_url(self):
         return f'https://confluence.ti8m.ch/docs/models/OCPProject/'
 
-    def ocp_project_get_yaml(self):
-        return {
-            'name': 'ti8m-squash-tm-added',
-            'description': 'An application to manage test cases from ti&m.',
-            'displayName': 'ti8m-squash-tm',
-            'customer': 'ti&m',
-            'owner': 'Tim R',
-            'contact': 'tim.rhomberg@ti8m.ch',
-            'workloads': 'Postgres DB, Squash-TM',
-            'request': 'SDTIM-12345',
-            'environments': {
-                'TST': [
-                    {
-                        'appEnv': 'tst',
-                        'monitoring': 'false',
-                        'postgresMonitoring': 'false',
-                        'kustomize': 'true',
-                        'deployment': {
-                            'repo': 'https://gitlab.ti8m.ch/edb/squash-tm-deployment.git',
-                            'branch': 'main',
-                            'path': 'overlays/tst'
-                        },
-                        'resourceQuota': {
-                            'requests': {
-                                'cpu': 2,
-                                'memory': '200Mi'
-                            },
-                            'limits': {
-                                'cpu': 1,
-                                'memory': 1
-                            }
-                        }
-                    }
-                ],
-                'INT': [
-                    {
-                        'appEnv': 'tst',
-                        'monitoring': 'true',
-                        'postgresMonitoring': 'true',
-                        'kustomize': 'true',
-                        'deployment': {
-                            'repo': 'https://gitlab.ti8m.ch/edb/squash-tm-deployment.git',
-                            'branch': 'main',
-                            'path': 'overlays/tst'
-                        },
-                        'resourceQuota': {
-                            'requests': {
-                                'cpu': 1,
-                                'memory': 1
-                            },
-                            'limits': {
-                                'cpu': 1,
-                                'memory': 1
-                            }
-                        }
-                    }
-                ],
-                'PRD': [
-                    {
-                        'appEnv': 'tst',
-                        'monitoring': 'true',
-                        'postgresMonitoring': 'true',
-                        'kustomize': 'true',
-                        'deployment': {
-                            'repo': 'https://gitlab.ti8m.ch/edb/squash-tm-deployment.git',
-                            'branch': 'main',
-                            'path': 'overlays/tst'
-                        },
-                        'resourceQuota': {
-                            'requests': {
-                                'cpu': 1,
-                                'memory': 1
-                            },
-                            'limits': {
-                                'cpu': 1,
-                                'memory': 1
-                            }
-                        }
-                    }
-                ]
-            }
-        }
+    def save(self, *args, **kwargs):
+        project_owner_pk = ContactRole.objects.get(name='Project Owner').pk
+        ocp_project_type_pk = ContentType.objects.get(app_label='ocp_project_plugin', model='ocpproject').pk
+
+        count_assignment = ContactAssignment.objects.filter(object_id=self.pk).count()
+        if count_assignment == 0:
+            ContactAssignment.objects.create(object_id=self.pk,
+                                             contact_id=self.contact.pk,
+                                             content_type_id=ocp_project_type_pk,
+                                             role_id=project_owner_pk)
+        else:
+            current_assignment = ContactAssignment.objects.get(object_id=self.pk, content_type_id=ocp_project_type_pk)
+            print(current_assignment.contact)
+            print(self.contact)
+            print(*args)
+            print(**kwargs)
+            if current_assignment.contact == self.contact:
+                print("Nothing changed in assignment")
+            else:
+                print("something changed in assignment")
+                current_assignment.contact = self.contact
+                current_assignment.save()
+        super(OCPProject, self).save(*args, **kwargs)
 
     def export_yaml_dict(self):
         yaml_object = {
@@ -185,14 +129,12 @@ class OCPProject(NetBoxModel):
         if len(self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_DEV)) > 0:
             yaml_object['environments']['DEV'] = self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_DEV)
         if len(self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_TST)) > 0:
-            app_env_list = self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_TST)
-            yaml_object['environments']['TST'] = app_env_list
+            yaml_object['environments']['TST'] = self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_TST)
         if len(self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_INT)) > 0:
             yaml_object['environments']['INT'] = self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_INT)
         if len(self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_PRD)) > 0:
             yaml_object['environments']['PRD'] = self.get_app_env(AppEnvironmentClusterEnvChoices.CHOICE_PRD)
 
-        get_queue("default").enqueue("ocp_project_plugin.worker.sync_project", yaml_object)
         print(yaml_object)
         return yaml_object
 
@@ -201,7 +143,7 @@ class OCPProject(NetBoxModel):
 
         app_env_list = []
         for app_env in app_env_queryset:
-            #@TODO deployment kind
+            # @TODO deployment kind
             app_env_list.append({
                 'appEnv': app_env.app_env,
                 'monitoring': app_env.monitoring,
@@ -213,11 +155,11 @@ class OCPProject(NetBoxModel):
                 },
                 'resourceQuota': {
                     'requests': {
-                        'cpu': app_env.requests_cpu,
+                        'cpu': str(app_env.requests_cpu),
                         'memory': app_env.requests_memory
                     },
                     'limits': {
-                        'cpu': app_env.limits_cpu,
+                        'cpu': str(app_env.limits_cpu),
                         'memory': app_env.limits_memory
                     }
                 }
@@ -327,14 +269,14 @@ class AppEnvironment(NetBoxModel):
     )
     ocp_project = ForeignKey(OCPProject, on_delete=CASCADE, related_name="app_env_ocp_project")
 
-    clone_fields = ["access_token", "cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind",
-                    "monitoring", "postgres_monitoring", "ocp_project", "requests_cpu", "requests_memory", "limits_cpu",
-                    "limits_memory"]
+    clone_fields = ["access_token", "cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip",
+                    "deployment_kind", "monitoring", "postgres_monitoring", "ocp_project", "requests_cpu",
+                    "requests_memory", "limits_cpu", "limits_memory"]
 
     class Meta:
-        ordering = ["access_token", "cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind",
-                    "monitoring", "postgres_monitoring", "ocp_project", "requests_cpu", "requests_memory", "limits_cpu",
-                    "limits_memory"]
+        ordering = ["access_token", "cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip",
+                    "deployment_kind", "monitoring", "postgres_monitoring", "ocp_project", "requests_cpu",
+                    "requests_memory", "limits_cpu", "limits_memory"]
 
     def __str__(self):
         return f"{self.cluster_env}-{self.app_env} ({self.repo}-{self.branch})"
@@ -347,8 +289,8 @@ class AppEnvironment(NetBoxModel):
         return f'https://confluence.ti8m.ch/docs/models/AppEnvironment/'
 
     def save(self, *args, **kwargs):
-        #get_queue("default").enqueue("ocp_project_plugin.worker.pull_repository")
-        print(self.ocp_project.export_yaml_dict())
+        yaml_object = self.ocp_project.export_yaml_dict()
+        get_queue("default").enqueue("ocp_project_plugin.worker.sync_project", yaml_object)
         super(AppEnvironment, self).save(*args, **kwargs)
 
     def get_cluster_color(self):
